# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import tekton
from tekton.models.v1alpha1_resource_param import V1alpha1ResourceParam  # noqa: E501
from tekton.rest import ApiException


class TestV1alpha1ResourceParam(unittest.TestCase):
    """V1alpha1ResourceParam unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1alpha1ResourceParam(self):
        """Test V1alpha1ResourceParam"""
        # FIXME: construct object with mandatory attributes with example values
        # model = tekton.models.v1alpha1_resource_param.V1alpha1ResourceParam()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
