# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import tekton
from tekton.models.v1beta1_condition_check import V1beta1ConditionCheck  # noqa: E501
from tekton.rest import ApiException


class TestV1beta1ConditionCheck(unittest.TestCase):
    """V1beta1ConditionCheck unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1beta1ConditionCheck(self):
        """Test V1beta1ConditionCheck"""
        # FIXME: construct object with mandatory attributes with example values
        # model = tekton.models.v1beta1_condition_check.V1beta1ConditionCheck()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
